// SPDX-License-Identifier: GPL-3.0-only
/*
 * Copyright (C) 2024  James Calligeros
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
import QtQuick
import QtQuick.Window
import QtQuick.Controls
import QtQml.Models
import org.kde.kirigami as Kirigami;

Item {

    Keys.onPressed: function(event) {
        switch (event.key) {
            case Qt.Key_Return:
            case Qt.Key_Enter:
                sddm.login(username.text,
                        pw.text,
                        session.currentIndex);
                return;
            default:
                return;
        }
    }

    visible: show_login
    Rectangle {
        id: title_bar
        width: parent.width
        height: 0.12 * base_height
        color: "#ff31363b"
        radius: 4
        z: 2

        Label {
            id: window_title
            text: "Log On to %1".arg(get_platform())
            x: 3
            y: 3
            z: 2
            color: "white"
            font.bold: true
        }
    }

    Rectangle {
        id: gina_window
        x: title_bar.x
        y: title_bar.y + (0.85 * title_bar.height)
        width: parent.width
        height: parent.height
        z: 2
        color: "#ffece9d8"
        Image {
            id: banner
            source: root.bg
            width: parent.width
            height: 0.40 * base_height
            fillMode: Image.PreserveAspectFit
            verticalAlignment: Image.AlignTop
            z: 4
        }

        TextField {
            id: username
            width: (0.70 * parent.width)
            x: (0.20 * parent.width)
            y: 1.10 * banner.height
            z: 3
            Label {
                id: username_label
                text: "User name:"
                x: -(1.05 * width)
                z: 3
            }

        }

        TextField {
            id: pw
            echoMode: TextInput.Password
            width: (0.70 * parent.width)
            x: (0.20 * parent.width)
            y: username.y + (1.20 * username.height)
            z: 3
            Label {
                id: password_label
                text: "Password:"
                x: -(1.05 * width)
                z: 3
            }
        }

        ComboBox {
            id: session
            model: sessionModel
            width: (0.70 * parent.width)
            currentIndex: model.lastIndex
            textRole: "name"
            x: (0.20 * parent.width)
            y: pw.y + (1.20 * pw.height)
            z: 3
            visible: show_options
            Label {
                id: session_label
                text: "Session:"
                x: -(1.05 * width)
                z: 3
            }
        }

        Button {
            id: dummy
            x: show_options ? btn_shutdown.x - width - (0.02 * gina_window.width) : btn_help.x - width - (0.02 * gina_window.width)
            y: btn_help.y
            z: 3
            text: "OK"
            onClicked: {
                sddm.login(username.text,
                        pw.text,
                        session.currentIndex);
            }
            visible: !show_shutdown
            Connections {
                target: sddm
                function onLoginFailed() {
                    username.text = ""
                    pw.text = ""
                }
            }
        }

        Button {
            id: btn_help
            x: (0.98 * parent.width) - width
            y: (0.98 * parent.height) - height
            z: 3
            text: show_options ? "Options <<" : "Options >>"
            onClicked: {
                show_options = !show_options;
            }
        }

        Button {
            id: btn_shutdown
            x: btn_help.x - width - (0.02 * parent.width)
            y: btn_help.y
            text: "Shut Down..."
            z: 3
            visible: show_options
            onClicked: {
                show_login = false;
                show_shutdown = true;
            }
        }
    }
}
