// SPDX-License-Identifier: GPL-3.0-only
/*
 * Copyright (C) 2024  James Calligeros
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
import QtQuick
import QtQuick.Window
import QtQuick.Controls
import org.kde.kirigami as Kirigami


Item {
    function trigger_shutdown(selected) {
        show_login = true;
        show_shutdown = false;
        switch (selected) {
            case "Shut down":
                sddm.powerOff();
                return;
            case "Restart":
                sddm.reboot();
                return;
            case "Sleep":
                sddm.suspend();
                return;
            case "Hibernate":
                sddm.hibernate();
                return;
            case "Hybrid Sleep":
                sddm.hybridSleep();
                return;
            default:
                return;
        }
    }

    Keys.onPressed: function(event) {
        switch (event.key) {
            case Qt.Key_Return:
            case Qt.Key_Enter:
                pwr.trigger_shutdown(pwr_options.currentText);
                return;
            default:
                return;
        }
    }

    visible: show_shutdown
    Rectangle {
        id: shutdown_title_bar
        width: parent.width
        height: 0.12 * base_height
        color: "#ff31363b"
        radius: 4
        visible: true
        z: 2

        Label {
            id: window_title
            text: "Power options for %1".arg(get_platform())
            x: 3
            y: 3
            z: 2
            color: "white"
            font.bold: true
        }
    }

    Rectangle {
        id: shutdown_window
        x: shutdown_title_bar.x
        y: shutdown_title_bar.y + (0.85 * shutdown_title_bar.height)
        width: parent.width
        height: parent.height
        z: 2
        visible: true
        color: "#ffece9d8"
        Image {
            id: banner
            source: root.bg
            width: parent.width
            height: 0.40 * base_height
            fillMode: Image.PreserveAspectFit
            verticalAlignment: Image.AlignTop
            visible: true
            z: 4
        }

        Label {
            id: prompt_label
            x: 0.20 * parent.width
            y: 1.10 * banner.height
            text: "What do you want the computer to do?"
            z: 4
        }

        ComboBox {
            id: pwr_options

            model: [
                {
                    name: "Shut down",
                    enabled: sddm.canPowerOff
                },
                {
                    name: "Restart",
                    enabled: sddm.canReboot
                },
                {
                    name: "Sleep",
                    enabled: sddm.canSuspend
                },
                {
                    name: "Hibernate",
                    enabled: sddm.canHibernate
                },
                {
                    name: "Hybrid Sleep",
                    enabled: sddm.canHybridSleep
                }
            ]

            delegate: ItemDelegate {
                width: pwr_options.width
                text: modelData.name
                font.weight: pwr_options.currentIndex === index ? Font.DemiBold : Font.Normal
                highlighted: ListView.isCurrentItem
                enabled: modelData.enabled
            }

            textRole: "name"
            currentIndex: 0
            width: (0.70 * shutdown_window.width)
            x: prompt_label.x
            y: prompt_label.y + (1.20 * prompt_label.height)
            z: 4
        }

        Kirigami.Icon {
            source: "computer"
            x: prompt_label.x - (1.05 * width)
            y: prompt_label.y
            width: pwr_options.height + prompt_label.height
            height: width
            z: 4
        }

        Button {
            id: btn_exit
            x: (shutdown_window.width - width) - (0.02 * shutdown_window.width)
            y: (shutdown_window.height - height) - (0.02 * shutdown_window.width)
            text: "Cancel"
            onClicked: {
                show_shutdown = false;
                show_login = true;
            }
            z: 4
        }

        Button {
            id: btn_ok
            x: btn_exit.x - width - (0.02 * shutdown_window.width); y: btn_exit.y
            text: "OK"
            z: 4
            onClicked: {
                trigger_shutdown(pwr_options.currentText)
            }
        }

        Label {
            text: "Ends your session and shuts down %1 so that\nyou can safely turn off power".arg(get_platform())
            x: pwr_options.x
            y: pwr_options.y + (1.20 * pwr_options.height)
            z: 4
            visible: pwr_options.currentText == "Shut down"
        }

        Label {
            text: "Shuts down %1, then restarts the computer".arg(get_platform())
            x: pwr_options.x
            y: pwr_options.y + (1.20 * pwr_options.height)
            z: 4
            visible: pwr_options.currentText == "Restart"
        }

        Label {
            text: "Suspends your session to RAM"
            x: pwr_options.x
            y: pwr_options.y + (1.20 * pwr_options.height)
            z: 4
            visible: pwr_options.currentText == "Sleep"
        }

        Label {
            text: "Saves your session to disk and shuts down the\ncomputer."
            x: pwr_options.x
            y: pwr_options.y + (1.20 * pwr_options.height)
            z: 4
            visible: pwr_options.currentText == "Hibernate"
        }

        Label {
            text: "Saves your session to disk and suspends to RAM."
            x: pwr_options.x
            y: pwr_options.y + (1.20 * pwr_options.height)
            z: 4
            visible: pwr_options.currentText == "Hybrid Sleep"
        }

    }
}
