// SPDX-License-Identifier: GPL-3.0-only
/*
 * Copyright (C) 2024  James Calligeros
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
import QtQuick
import QtQuick.Window
import QtQuick.Controls
import QtQml.Models
import org.kde.kirigami as Kirigami;
import "Components"

Item {
    property var show_login: true
    property var show_options: false
    property var show_shutdown: false
    property var base_height: 200
    property var bg: Qt.resolvedUrl(config.stringValue("banner"))

    function get_platform() {
        switch (Qt.platform.os) {
            case "linux":
                return "Linux"
            case "unix":
                return "*nix"
            default:
                return "Unknown Platform"
        }
    }

    id: root
    width: screen.width
    height: screen.height
    z: 0
    anchors.fill: parent
    visible: true

    Rectangle {
        id: background
        anchors.fill: parent
        width: root.width
        height: root.height
        z: 0
        color: "#ff004e98"
    }

    Login {
        id: login_window
        width: 460
        height: show_options ? 1.15 * base_height : base_height
        x: (root.width / 2) - (width / 2)
        y: (root.height / 2) - (base_height / 2)
    }

    Shutdown {
        id: pwr
        x: login_window.x
        y: login_window.y
        width: login_window.width
        height: login_window.height
    }
}
